Add vendor ID for AMBIT and use it to set the ath5k LED gpio.

base.c:
Changes-licensed-under: 3-Clause-BSD

Signed-off-by: Tulio Magno Quites Machado Filho <tul...@gmail.com>
---
 drivers/net/wireless/ath5k/base.c |    8 ++++++--
 include/linux/pci_ids.h           |    2 ++
 2 files changed, 8 insertions(+), 2 deletions(-)

diff --git a/include/linux/pci_ids.h b/include/linux/pci_ids.h
index 02e6046..402ab74 100644
--- a/include/linux/pci_ids.h
+++ b/include/linux/pci_ids.h
@@ -836,6 +836,8 @@
 
 #define PCI_VENDOR_ID_FOXCONN          0x105b
 
+#define PCI_VENDOR_ID_AMBIT            0x1468
+
 #define PCI_VENDOR_ID_UMC              0x1060
 #define PCI_DEVICE_ID_UMC_UM8673F      0x0101
 #define PCI_DEVICE_ID_UMC_UM8886BF     0x673a
diff --git a/drivers/net/wireless/ath5k/base.c 
b/drivers/net/wireless/ath5k/base.c
index 57971a9..180518c 100644
--- a/drivers/net/wireless/ath5k/base.c
+++ b/drivers/net/wireless/ath5k/base.c
@@ -2626,8 +2626,12 @@ ath5k_init_leds(struct ath5k_softc *sc)
                sc->led_pin = 1;
                sc->led_on = 1;  /* active high */
        }
-       /* Pin 3 on Foxconn chips used in Acer Aspire One (0x105b:e008) */
-       if (pdev->subsystem_vendor == PCI_VENDOR_ID_FOXCONN) {
+       /*
+        * Pin 3 on Foxconn chips used in Acer Aspire One (0x105b:e008) and
+        * in emachines notebooks with AMBIT subsystem.
+        */
+       if (pdev->subsystem_vendor == PCI_VENDOR_ID_FOXCONN ||
+           pdev->subsystem_vendor == PCI_VENDOR_ID_AMBIT) {
                __set_bit(ATH_STAT_LEDSOFT, sc->status);
                sc->led_pin = 3;
                sc->led_on = 0;  /* active low */
-- 
1.6.0.2

_______________________________________________
ath5k-devel mailing list
ath5k-devel@lists.ath5k.org
https://lists.ath5k.org/mailman/listinfo/ath5k-devel

Reply via email to